diff --git a/src/routes/+layout.svelte b/src/routes/+layout.svelte
index a51db47..4ce64a1 100644
--- a/src/routes/+layout.svelte
+++ b/src/routes/+layout.svelte
@@ -122,6 +122,7 @@
--color-callout-warn: var(--color-highlight-alt);
--color-callout-quote: #354CBE;
+ --color-callout-info: #AC7F31;
/* blurs */
--blur-radius-background: 6px;
diff --git a/src/routes/blog/2026/0317.md b/src/routes/blog/2026/0317.md
index 11b47d0..6562072 100644
--- a/src/routes/blog/2026/0317.md
+++ b/src/routes/blog/2026/0317.md
@@ -1,8 +1,14 @@
-
-
Note: as I'm constantly learning new things, this blog post is sort of outdated now. The information is still correct, but it feels inefficient and leads into a dead-end. I dislike this, as I wanted to write a guide that provides an expandable base. Therefore, I'll likely either update or replace this article and trim it down to focus on the important bits.
+
-
Expect a Go API.
-
+
Note: as I'm constantly learning new things, this blog post is sort of outdated now. The information is still correct, but it feels inefficient and leads into a dead-end. I dislike this, as I wanted to write a guide that provides an expandable base. Therefore, I'll likely either update or replace this article and trim it down to focus on the important bits.",
+ "Expect a Go API.",
+ ]}
+ />
*Hey!*
diff --git a/src/lib/components/callout.svelte b/src/lib/components/callout.svelte
index dc165e3..5de75bf 100644
--- a/src/lib/components/callout.svelte
+++ b/src/lib/components/callout.svelte
@@ -5,7 +5,7 @@
}: {
content: string[];
// valid values: warn, quote. defaults to warn
type: string;
} = $props();
@@ -14,6 +14,8 @@
{#if type == "quote"}
ยป
+ {:else if type == "info"}
+ i
{:else}
!
{/if}
@@ -33,6 +35,10 @@
{@render calloutContent()}
+{:else if type == "info"}
+
+ {@render calloutContent()}
+
{:else}
{@render calloutContent()}
@@ -48,12 +54,16 @@
--color-callout: var(--color-callout-quote);
}
+ .callout-info {
+ --color-callout: var(--color-callout-info);
+ }
+
.callout-container {
--color-callout-background: color-mix(in srgb, var(--color-callout) 30%, transparent);
display: flex;
flex-direction: row;
max-width: 800px;
- margin: 0 auto;
+ margin: 12px auto 0;
align-items: center;
border: var(--border-style) var(--border-dash-size) var(--color-callout);
background-color: var(--color-callout-background);
@@ -5,7 +5,7 @@
}: {
content: string[];
- // valid values: warn, quote. defaults to warn
+ // valid values: warn, quote, info. defaults to warn
type: string;
} = $props();